Animation class

Constructors

Animation(KeyframeEffect effect, AnimationTimeline? timeline)

Properties

currentTime ↔ double?
getter/setter pair
effect ↔ AnimationEffect?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
oncancel ↔ Function?
getter/setter pair
onfinish ↔ Function?
getter/setter pair
onremove ↔ Function?
getter/setter pair
onstart ↔ Function?
getter/setter pair
pending → bool
no setter
playbackRate ↔ double
getter/setter pair
playState → AnimationPlayState
no setter
progress → double
no setter
replaceState → AnimationReplaceState?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime ↔ double?
getter/setter pair
timeline ↔ AnimationTimeline?
getter/setter pair

Methods

cancel() → void
dispose() → void
finish() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause() → void
persist() → void
play() → void
reverse() → void
toString() → String
A string representation of this object.
inherited
updatePlaybackRate() → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited