AnimationEffect class

Implementers

Constructors

AnimationEffect()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timing ↔ EffectTiming?
getter/setter pair

Methods

getComputedTiming() → Map
getTiming() → EffectTiming?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
updateTiming(Map<String, dynamic> optionalEffectTiming) → dynamic

Operators

operator ==(Object other) → bool
The equality operator.
inherited