CSSBackgroundImage class

Constructors

CSSBackgroundImage(List<CSSFunctionalNotation> functions, RenderStyle renderStyle, WebFController controller, {String? baseHref, double? gradientLengthHint})

Properties

baseHref ↔ String?
getter/setter pair
controller ↔ WebFController
getter/setter pair
functions ↔ List<CSSFunctionalNotation>
getter/setter pair
gradient → Gradient?
no setter
gradientLengthHint → double?
final
hashCode → int
The hash code for this object.
no setterinherited
image → ImageProvider<Object>?
no setter
renderStyle ↔ RenderStyle
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

cssText() → String
dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
warmUpImage() → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited