CSSBackgroundPosition class

Constructors

CSSBackgroundPosition({CSSLengthValue? length, double? percentage, CSSCalcValue? calcValue})

Properties

calcValue ↔ CSSCalcValue?
Relative position to image container when keyword or calcValue type is set.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
length ↔ CSSLengthValue?
Absolute position to image container when length type is set.
getter/setter pair
percentage ↔ double?
Relative position to image container when keyword or percentage type is set.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

cssText() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited