CSSColor class

#123 #123456 rgb(r,g,b) rgba(r,g,b,a)

Mixed-in types

Constructors

CSSColor(Color value)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ Color
getter/setter pair

Methods

cssText() → String
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

clearCachedColorValue(String color) → void
convertToHex(Color color) → String
isColor(String color) → bool
parseColor(String color, {RenderStyle? renderStyle, String? propertyName}) → Color?
resolveColor(String color, RenderStyle renderStyle, String propertyName) → CSSColor?
tranformToDarkColor(Color color) → Color
transformToLightColor(Color color) → Color
tryParserCSSColorWithVariable(String fullColor, String input, RenderStyle renderStyle, String propertyName) → String

Constants

HSL → const String
HSLA → const String
initial → const Color
INITIAL_COLOR → const String
RGB → const String
RGBA → const String
transparent → const Color