CSSGridParser class

Constructors

CSSGridParser()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

isCustomIdent(String token) → bool
parseAutoFlow(String value) → GridAutoFlow
parseAxisAlignment(String value, {bool allowAuto = false}) → GridAxisAlignment
parsePlacement(String value) → GridPlacement
parseTemplateAreas(String value) → GridTemplateAreasDefinition?
parseTrackList(String value, RenderStyle renderStyle, String propertyName, Axis axis) → List<GridTrackSize>