CSSKeyframesRule class

Inheritance

Constructors

CSSKeyframesRule(int _keyframeName, String name)

Properties

cssText → String
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
keyFrameName → String?
no setter
keyframes → List<Keyframe>
final
layerOrderKey ↔ List<int>?
Cached cascade layer sort key, assigned by RuleSet when rules are added. null means unlayered.
getter/setter pairinherited
layerPath ↔ List<String>
Cascade layer path segments for this rule (e.g. ['framework', 'utilities']). Empty means unlayered.
getter/setter pairinherited
name → String
final
parentStyleSheet ↔ CSSStyleSheet?
getter/setter pairinherited
position ↔ int
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → int
no setteroverride

Methods

add(KeyFrameBlock block) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited