CSSLengthValue class

Constructors

CSSLengthValue(double? value, CSSLengthType type, [RenderStyle? renderStyle, String? propertyName, Axis? axisType])
CSSLengthValue.calc(CSSCalcValue? calcValue, RenderStyle? renderStyle, String? propertyName)

Properties

axisType ↔ Axis?
getter/setter pair
calcValue → CSSCalcValue?
final
computedValue → double
no setter
hashCode → int
The hash code for this object.
no setteroverride
isAuto → bool
no setter
isFitContent → bool
no setter
isIntrinsic → bool
no setter
isMaxContent → bool
no setter
isMinContent → bool
no setter
isNone → bool
no setter
isNotAuto → bool
no setter
isNotNone → bool
no setter
isPercentage → bool
no setter
isPrecise → bool
no setter
isZero → bool
no setter
propertyName ↔ String?
getter/setter pair
renderStyle ↔ RenderStyle?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → CSSLengthType
final
value → double?
final

Methods

cssText() → String
isViewportSizeRelatedLength() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
Compares two length for equality.
override

Static Properties

auto → CSSLengthValue
final
initial → CSSLengthValue
final
none → CSSLengthValue
final
normal → CSSLengthValue
final
unknown → CSSLengthValue
final
zero → CSSLengthValue
final