CSSMediaQuery class

MediaQuery grammar:

 : [ONLY | NOT]? S* media_type S* [ AND S* media_expression ]*
 | media_expression [ AND S* media_expression ]*
media_type
 : IDENT
media_expression
 : '(' S* media_feature S* [ ':' S* expr ]? ')' S*
media_feature
 : IDENT
Inheritance

Constructors

CSSMediaQuery(int _mediaUnary, Identifier? _mediaType, List<CSSMediaExpression> expressions)

Properties

expressions → List<CSSMediaExpression>
final
hashCode → int
The hash code for this object.
no setterinherited
hasMediaType → bool
no setter
hasUnary → bool
no setter
mediaType → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unary → String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
visit(Visitor visitor) → dynamic
Classic double-dispatch visitor for implementing passes.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited