CSSOrigin class

Constructors

CSSOrigin(Offset offset, Alignment alignment)
const

Properties

alignment → Alignment
final
hashCode → int
The hash code for this object.
no setterinherited
offset → Offset
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

parseOrigin(String origin, RenderStyle renderStyle, String property) → CSSOrigin?