CSSPaint class

Constructors

CSSPaint(CSSPaintType type, {Color? color})
const

Properties

color → Color?
final
hashCode → int
The hash code for this object.
no setterinherited
isNone → dynamic
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → CSSPaintType
final

Methods

cssText() → String
getColor() → Color
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(RenderStyle renderStyle) → Color
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

parsePaint(String paint, {required RenderStyle renderStyle}) → CSSPaint?

Constants

blackPaint → const CSSPaint
contextFill → const CSSPaint
contextStroke → const CSSPaint
currentColor → const CSSPaint
none → const CSSPaint