CSSParsedLengthValue class

Constructors

CSSParsedLengthValue(double? value, CSSLengthType type)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → CSSLengthType
final
value → double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(RenderStyle renderStyle, String propertyName, [Axis? axisType]) → CSSLengthValue
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

tryParse(String text) → CSSParsedLengthValue?