CSSParser class

Constructors

CSSParser(String text, {int start = 0, String? href})

Properties

hashCode → int
The hash code for this object.
no setterinherited
href ↔ String?
A string containing the baseURL used to resolve relative URLs in the stylesheet.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tokenizer → Tokenizer
final

Methods

checkEndOfFile() → void
Generate an error if file has not been completely consumed.
identifier() → Identifier
isPrematureEndOfFile() → bool
Guard to break out of parser when an unexpected end of file is found.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse({double? windowWidth, double? windowHeight, bool? isDarkMode}) → CSSStyleSheet
Main entry point for parsing an entire CSS file.
parseInlineStyle() → Map<String, dynamic>
parseInlineStyleWithImportant() → InlineStyleParseResult
parseRules({double? windowWidth, double? windowHeight, bool? isDarkMode}) → List<CSSRule>
parseSelector() → List<Selector>
Main entry point for parsing a simple selector sequence.
processAttribute() → SimpleSelector?
processCalcExpression() → String
processCompoundSelector() → Selector?
Same as processSelector but reports an error for each combinator.
processDeclaration(CSSStyleDeclaration style) → void
processDeclarations({bool checkBrace = true}) → List
processDirective() → CSSRule?
Directive grammar:
processExpr([bool ieFilter = false]) → String?
processForgivingSelectorGroup({required int terminatorKind}) → SelectorGroup?
processFunction(Identifier func) → dynamic
processGroupRuleBody() → List<CSSRule>
processLayerDirective() → List<CSSRule>?
Parses @layer ... and returns rules.
processMediaExpression([String op = MediaOperator.AND]) → CSSMediaExpression?
processMediaQuery() → CSSMediaQuery?
//////////////////////////////////////////////////////////////// ////////////////////////////////////////////////////////////////
processPseudoSelector(FileSpan start) → SimpleSelector?
processQuotedString([bool urlString = false]) → String
processRule([SelectorGroup? selectorGroup]) → List<CSSRule>?
processSelector() → Selector?
Return list of selectors
processSelectorExpression() → List<String>
In CSS3, the expressions are identifiers, strings, or of the form "an+b".
processSelectorGroup() → SelectorGroup?
simpleSelector() → SimpleSelector?
Simple selector grammar:
simpleSelectorSequence(bool forceCombinatorNone) → SimpleSelectorSequence?
simpleSelectorTail() → SimpleSelector?
type_selector | universal | HASH | class | attrib | pseudo
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

MAX_UNICODE → const int