left property

  1. @override
CSSLengthValue get left
override

Implementation

@override
CSSLengthValue get left {
  final CSSLengthValue physical = _left ?? CSSLengthValue.auto;
  // Keep logical values so they can remap when `direction` changes. When a
  // physical side is explicitly specified, it should override the logical
  // fallback (matches paddingInlineStart/end behavior).
  final CSSLengthValue? logical =
      (direction == TextDirection.rtl) ? _insetInlineEnd : _insetInlineStart;
  if (_left != null) return physical;
  return logical ?? physical;
}
set left (CSSLengthValue? value)

Implementation

set left(CSSLengthValue? value) {
  if (_left == value) {
    return;
  }
  _left = value;
  _markContainingBlockNeedsLayout();
}