CSSPositionedLayout class

Constructors

CSSPositionedLayout()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

applyPositionedChildOffset(RenderBoxModel parent, RenderBoxModel child) → void
applyRelativeOffset(Offset? relativeOffset, RenderBox renderBox) → void
applyStickyChildOffset(RenderBoxModel parent, RenderBoxModel child, {RenderBoxModel? scrollContainer}) → void
getRelativeOffset(RenderStyle renderStyle) → Offset?
isSticky(RenderBoxModel child) → bool
layoutPositionedChild(RenderBoxModel parent, RenderBoxModel child, {bool needsRelayout = false}) → void