CSSRuleListBinding class

Inheritance
Mixed-in types
Available extensions

Constructors

CSSRuleListBinding(BindingContext context, CSSStyleSheetBinding _sheetBinding, List<CSSRule> _rulesProvider())

Properties

asyncMethods → List<StaticDefinedAsyncBindingObjectMethodMap>
no setterinherited
contextId → double?
no setterinherited
dynamicMethods → Map<String, BindingObjectMethod>
no setterinherited
dynamicProperties → Map<String, BindingObjectProperty>
no setterinherited
first → dynamic
The first element.
no setterinherited
firstOrNull → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The first element of this iterator, or null if the iterable is empty.
no setter
hashCode → int
The hash code for this object.
no setterinherited
indexed → Iterable<(int, T)>

Available on Iterable<T>, provided by the IterableExtensions extension

Pairs of elements of the indices and elements of this iterable.
no setter
isEmpty → bool
Whether this collection has no elements.
no setterinherited
isNotEmpty → bool
Whether this collection has at least one element.
no setterinherited
iterator → Iterator
A new Iterator that allows iterating the elements of this Iterable.
no setterinherited
last → dynamic
The last element.
no setterinherited
lastOrNull → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The last element of this iterable, or null if the iterable is empty.
no setter
length → int
The number of elements in this Iterable.
no setteroverride
methods → List<StaticDefinedSyncBindingObjectMethodMap>
no setteroverride
nonNulls → Iterable<T>

Available on Iterable<T?>, provided by the NullableIterableExtensions extension

The non-null elements of this iterable.
no setter
ownerView → WebFViewController
no setterinherited
pointer → Pointer<NativeBindingObject>
no setteroverride
properties → List<StaticDefinedBindingPropertyMap>
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
single → dynamic
Checks that this iterable has only one element, and returns that element.
no setterinherited
singleOrNull → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The single element of this iterator, or null.
no setter
toJSIterable → JSIterable<T>

Available on Iterable<T>, provided by the IterableToJSIterable extension

A JSIterable wrapper that proxies to the Dart iterable API.
no setter
wait → Future<List<T>>

Available on Iterable<Future<T>>, provided by the FutureIterable extension

Waits for futures in parallel.
no setter

Methods

any(bool test(dynamic element)) → bool
Checks whether any element of this iterable satisfies test.
inherited
asNameMap() → Map<String, T>

Available on Iterable<T>, provided by the EnumByName extension

Creates a map from the names of enum values to the values.
byName(String name) → T

Available on Iterable<T>, provided by the EnumByName extension

Finds the enum value in this list with name name.
cast<R>() → Iterable<R>
A view of this iterable as an iterable of R instances.
inherited
contains(Object? element) → bool
Whether the collection contains an element equal to element.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
dispose() → void
inherited
elementAt(int index) → dynamic
Returns the indexth element.
inherited
elementAtOrNull(int index) → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The element at position index of this iterable, or null.
every(bool test(dynamic element)) → bool
Checks whether every element of this iterable satisfies test.
inherited
expand<T>(Iterable<T> toElements(dynamic element)) → Iterable<T>
Expands each element of this Iterable into zero or more elements.
inherited
firstWhere(bool test(dynamic element), {dynamic orElse()?}) → dynamic
The first element that satisfies the given predicate test.
inherited
fold<T>(T initialValue, T combine(T previousValue, dynamic element)) → T
Reduces a collection to a single value by iteratively combining each element of the collection with an existing value
inherited
followedBy(Iterable other) → Iterable
Creates the lazy concatenation of this iterable and other.
inherited
forEach(void action(dynamic element)) → void
Invokes action on each element of this iterable in iteration order.
inherited
getStaticDefinedAsyncMethod(String method) → StaticDefinedAsyncBindingObjectMethod?
inherited
getStaticDefinedProperty(String key) → StaticDefinedBindingProperty?
inherited
getStaticDefinedSyncMethod(String method) → StaticDefinedSyncBindingObjectMethod?
inherited
initializeDynamicMethods(Map<String, BindingObjectMethod> methods) → void
inherited
initializeDynamicProperties(Map<String, BindingObjectProperty> properties) → void
inherited
initializeMethods(Map<String, BindingObjectMethod> methods) → void
inherited
initializeProperties(Map<String, BindingObjectProperty> properties) → void
inherited
item(int index) → CSSRuleBindingBase?
join([String separator = ""]) → String
Converts each element to a String and concatenates the strings.
inherited
lastWhere(bool test(dynamic element), {dynamic orElse()?}) → dynamic
The last element that satisfies the given predicate test.
inherited
map<T>(T toElement(dynamic e)) → Iterable<T>
The current elements of this iterable modified by toElement.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reduce(dynamic combine(dynamic value, dynamic element)) → dynamic
Reduces a collection to a single value by iteratively combining elements of the collection using the provided function.
inherited
refresh() → void
singleWhere(bool test(dynamic element), {dynamic orElse()?}) → dynamic
The single element that satisfies test.
inherited
skip(int count) → Iterable
Creates an Iterable that provides all but the first count elements.
inherited
skipWhile(bool test(dynamic element)) → Iterable
Creates an Iterable that skips leading elements while test is satisfied.
inherited
take(int count) → Iterable
Creates a lazy iterable of the count first elements of this iterable.
inherited
takeWhile(bool test(dynamic element)) → Iterable
Creates a lazy iterable of the leading elements satisfying test.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toList({bool growable = true}) → List
Creates a List containing the elements of this Iterable.
inherited
toSet() → Set
Creates a Set containing the same elements as this iterable.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
where(bool test(dynamic element)) → Iterable
Creates a new lazy Iterable with all elements that satisfy the predicate test.
inherited
whereType<T>() → Iterable<R>
Creates a new lazy Iterable with all elements that have type T.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited