CSSStyleDeclaration class

The CSSStyleDeclaration interface represents an object that is a CSS declaration block, and exposes style information and various style-related methods and properties.

A CSSStyleDeclaration object can be exposed using three different APIs:

  1. Via HTMLElement.style, which deals with the inline styles of a single element (e.g.,
    ).
  2. Via the CSSStyleSheet API. For example, document.styleSheets0.cssRules0.style returns a CSSStyleDeclaration object on the first CSS rule in the document's first stylesheet.
  3. Via Window.getComputedStyle(), which exposes the CSSStyleDeclaration object as a read-only interface.
Inheritance
Mixed-in types
Implementers
Available extensions

Constructors

CSSStyleDeclaration([BindingContext? context])
CSSStyleDeclaration.computedStyle(Element? target, Map<String, dynamic>? defaultStyle, StyleChangeListener? onStyleChanged, [StyleFlushedListener? onStyleFlushed])

Properties

asyncMethods → List<StaticDefinedAsyncBindingObjectMethodMap>
no setterinherited
contextId → double?
no setterinherited
cssText → String
Textual representation of the declaration block. Setting this attribute changes the style.
no setter
defaultStyle ↔ Map<String, dynamic>?
getter/setter pair
dynamicMethods → Map<String, BindingObjectMethod>
no setterinherited
dynamicProperties → Map<String, BindingObjectProperty>
no setterinherited
first → dynamic
The first element.
no setterinherited
firstOrNull → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The first element of this iterator, or null if the iterable is empty.
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasImportantDeclarations → bool
no setter
hasInheritedPendingProperty → bool
no setter
hasPendingProperties → bool
no setter
indexed → Iterable<(int, T)>

Available on Iterable<T>, provided by the IterableExtensions extension

Pairs of elements of the indices and elements of this iterable.
no setter
isEmpty → bool
Whether this collection has no elements.
no setterinherited
isNotEmpty → bool
Whether this collection has at least one element.
no setterinherited
iterator → Iterator<MapEntry<String, CSSPropertyValue>>
A new Iterator that allows iterating the elements of this Iterable.
no setteroverride
last → dynamic
The last element.
no setterinherited
lastOrNull → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The last element of this iterable, or null if the iterable is empty.
no setter
length → int
The number of properties.
no setteroverride
methods → List<StaticDefinedSyncBindingObjectMethodMap>
no setterinherited
nonNulls → Iterable<T>

Available on Iterable<T?>, provided by the NullableIterableExtensions extension

The non-null elements of this iterable.
no setter
onStyleChanged ↔ StyleChangeListener?
getter/setter pair
onStyleFlushed ↔ StyleFlushedListener?
getter/setter pair
ownerView → WebFViewController
no setterinherited
pointer → Pointer<NativeBindingObject>?
no setterinherited
properties → List<StaticDefinedBindingPropertyMap>
no setterinherited
pseudoAfterStyle ↔ CSSStyleDeclaration?
getter/setter pair
pseudoBeforeStyle ↔ CSSStyleDeclaration?
getter/setter pair
pseudoFirstLetterStyle ↔ CSSStyleDeclaration?
getter/setter pair
pseudoFirstLineStyle ↔ CSSStyleDeclaration?
getter/setter pair
resolvedPseudoAfterStyle → CSSStyleDeclaration?
no setter
resolvedPseudoBeforeStyle → CSSStyleDeclaration?
no setter
resolvedPseudoFirstLetterStyle → CSSStyleDeclaration?
no setter
resolvedPseudoFirstLineStyle → CSSStyleDeclaration?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
single → dynamic
Checks that this iterable has only one element, and returns that element.
no setterinherited
singleOrNull → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The single element of this iterator, or null.
no setter
structuralHashCode → int
no setter
target ↔ Element?
getter/setter pair
toJSIterable → JSIterable<T>

Available on Iterable<T>, provided by the IterableToJSIterable extension

A JSIterable wrapper that proxies to the Dart iterable API.
no setter
wait → Future<List<T>>

Available on Iterable<Future<T>>, provided by the FutureIterable extension

Waits for futures in parallel.
no setter

Methods

addStyleChangeListener(StyleChangeListener listener) → void
any(bool test(dynamic element)) → bool
Checks whether any element of this iterable satisfies test.
inherited
asNameMap() → Map<String, T>

Available on Iterable<T>, provided by the EnumByName extension

Creates a map from the names of enum values to the values.
byName(String name) → T

Available on Iterable<T>, provided by the EnumByName extension

Finds the enum value in this list with name name.
cast<R>() → Iterable<R>
A view of this iterable as an iterable of R instances.
inherited
clearPseudoStyle(String type) → void
cloneEffective() → CSSStyleDeclaration
contains(Object? property) → bool
Check a css property is valid.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
dispose() → Future<void>
override
elementAt(int index) → dynamic
Returns the indexth element.
inherited
elementAtOrNull(int index) → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The element at position index of this iterable, or null.
every(bool test(dynamic element)) → bool
Checks whether every element of this iterable satisfies test.
inherited
expand<T>(Iterable<T> toElements(dynamic element)) → Iterable<T>
Expands each element of this Iterable into zero or more elements.
inherited
firstWhere(bool test(dynamic element), {dynamic orElse()?}) → dynamic
The first element that satisfies the given predicate test.
inherited
flushDisplayProperties() → void
flushPendingProperties() → void
fold<T>(T initialValue, T combine(T previousValue, dynamic element)) → T
Reduces a collection to a single value by iteratively combining each element of the collection with an existing value
inherited
followedBy(Iterable other) → Iterable
Creates the lazy concatenation of this iterable and other.
inherited
forEach(void action(dynamic element)) → void
Invokes action on each element of this iterable in iteration order.
inherited
getPropertyBaseHref(String propertyName) → String?
Returns the baseHref associated with a property value if available.
getPropertyValue(String propertyName) → String
Returns the property value given a property name. value is a String containing the value of the property. If not set, returns the empty string.
getStaticDefinedAsyncMethod(String method) → StaticDefinedAsyncBindingObjectMethod?
inherited
getStaticDefinedProperty(String key) → StaticDefinedBindingProperty?
inherited
getStaticDefinedSyncMethod(String method) → StaticDefinedSyncBindingObjectMethod?
inherited
handlePseudoRules(Element parentElement, List<CSSStyleRule> rules) → void
initializeDynamicMethods(Map<String, BindingObjectMethod> methods) → void
inherited
initializeDynamicProperties(Map<String, BindingObjectProperty> properties) → void
inherited
initializeMethods(Map<String, BindingObjectMethod> methods) → void
inherited
initializeProperties(Map<String, BindingObjectProperty> properties) → void
inherited
isImportant(String propertyName) → bool
Whether the given property is marked as !important on this declaration.
item(int index) → String
Returns a property name.
join([String separator = ""]) → String
Converts each element to a String and concatenates the strings.
inherited
lastWhere(bool test(dynamic element), {dynamic orElse()?}) → dynamic
The last element that satisfies the given predicate test.
inherited
map<T>(T toElement(dynamic e)) → Iterable<T>
The current elements of this iterable modified by toElement.
inherited
merge(CSSStyleDeclaration other) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reduce(dynamic combine(dynamic value, dynamic element)) → dynamic
Reduces a collection to a single value by iteratively combining elements of the collection using the provided function.
inherited
removeProperty(String propertyName, [bool? isImportant]) → void
Removes a property from the CSS declaration.
removePseudoProperty(String type, String propertyName) → void
removeStyleChangeListener(StyleChangeListener listener) → void
reset() → void
setProperty(String propertyName, String? value, {bool? isImportant, String? baseHref, bool validate = true}) → void
Modifies an existing CSS property or creates a new CSS property in the declaration block.
setPseudoProperty(String type, String propertyName, String value, {String? baseHref, bool validate = true}) → void
singleWhere(bool test(dynamic element), {dynamic orElse()?}) → dynamic
The single element that satisfies test.
inherited
skip(int count) → Iterable
Creates an Iterable that provides all but the first count elements.
inherited
skipWhile(bool test(dynamic element)) → Iterable
Creates an Iterable that skips leading elements while test is satisfied.
inherited
structurallyEquals(CSSStyleDeclaration other) → bool
take(int count) → Iterable
Creates a lazy iterable of the count first elements of this iterable.
inherited
takeWhile(bool test(dynamic element)) → Iterable
Creates a lazy iterable of the leading elements satisfying test.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toList({bool growable = true}) → List
Creates a List containing the elements of this Iterable.
inherited
toSet() → Set
Creates a Set containing the same elements as this iterable.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
Returns a string representation of (some of) the elements of this.
override
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
union(CSSStyleDeclaration declaration) → void
unionByImportance(CSSStyleDeclaration declaration, {required bool important}) → void
Like union, but only applies declarations matching important.
where(bool test(dynamic element)) → Iterable
Creates a new lazy Iterable with all elements that satisfy the predicate test.
inherited
whereType<T>() → Iterable<R>
Creates a new lazy Iterable with all elements that have type T.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](String property) → dynamic
operator []=(String property, dynamic value) → void

Static Properties

empty ↔ CSSStyleDeclaration
An empty style declaration.
getter/setter pair

Static Methods

isNullOrEmptyValue(dynamic value) → bool