CSSStyleRule class

Inheritance

Constructors

CSSStyleRule(SelectorGroup selectorGroup, CSSStyleDeclaration declaration)

Properties

cssText → String
no setteroverride
declaration → CSSStyleDeclaration
final
hashCode → int
The hash code for this object.
no setterinherited
layerOrderKey ↔ List<int>?
Cached cascade layer sort key, assigned by RuleSet when rules are added. null means unlayered.
getter/setter pairinherited
layerPath ↔ List<String>
Cascade layer path segments for this rule (e.g. ['framework', 'utilities']). Empty means unlayered.
getter/setter pairinherited
parentStyleSheet ↔ CSSStyleSheet?
getter/setter pairinherited
position ↔ int
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectorGroup → SelectorGroup
final
structuralHashCode → int
no setter
type → int
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
structurallyEquals(CSSStyleRule other) → bool
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited