CSSStyleSheet class

Implemented types

Constructors

CSSStyleSheet(List<CSSRule> cssRules, {bool disabled = false, String? href})

Properties

cssRules → List<CSSRule>
final
disabled ↔ bool
A Boolean indicating whether the stylesheet is disabled. False by default.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
href ↔ String?
A string containing the baseURL used to resolve relative URLs in the stylesheet.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
structuralHashCode → int
no setter
type ↔ String
getter/setter pair

Methods

clone() → CSSStyleSheet
compareTo(dynamic other) → int
Compares this object to another object.
override
deleteRule(int index) → dynamic
Removes a rule from the stylesheet object.
insertRule(String text, int index, {required double windowWidth, required double windowHeight, required bool isDarkMode}) → int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replaceSync(String text, {required double windowWidth, required double windowHeight, required bool? isDarkMode}) → dynamic
Synchronously replaces the content of the stylesheet with the content passed into it.
structurallyEquals(CSSStyleSheet other) → bool
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited