CSSText class

Constructors

CSSText()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

builtinFontPackage ↔ String?
getter/setter pair
defaultFontFamilyFallback ↔ List<String>?
getter/setter pair
defaultFontSize ↔ CSSLengthValue
getter/setter pair
defaultLineHeight ↔ CSSLengthValue
getter/setter pair

Static Methods

applyTextTransform(String input, TextTransform transform) → String
applyTextTransformWithCarry(String input, TextTransform transform, bool atWordStart) → (String, bool)
getBackground() → Paint?
getFontPackage() → String?
getForeground() → Paint?
getLocale() → Locale?
getTextBaseLine() → TextBaseline
isValidFontSizeValue(String value) → bool
isValidFontStyleValue(String value) → bool
isValidFontVariantCss21Value(String value) → bool
isValidFontVariantValue(String value) → bool
isValidFontWeightValue(String value) → bool
isValidLineHeightValue(String value) → bool
isValidTextTextDecorationLineValue(String value) → bool
isValidTextTextDecorationStyleValue(String value) → bool
isWordBoundary(int codeUnit) → bool
parseLineClamp(String value) → int?
resolveFontFamilyFallback(String? fontFamily) → List<String>
resolveFontFeaturesForVariant(CSSRenderStyle renderStyle) → ({List<FontFeature> features, FontVariantCapsSynthesis synth})
resolveFontSize(String fontSize, RenderStyle renderStyle, String propertyName) → CSSLengthValue
resolveFontStyle(String? fontStyle) → FontStyle
resolveFontVariant(String? fontVariant) → String?
resolveFontWeight(String? fontWeight) → FontWeight
resolveLineHeight(String value, RenderStyle renderStyle, String propertyName) → CSSLengthValue?
resolveSpacing(String spacing, RenderStyle renderStyle, String property) → CSSLengthValue
resolveTextDecorationLine(String present) → TextDecoration
In CSS2.1, text-decoration determin the type of text decoration, but in CSS3, which is text-decoration-line. This resolver accepts multiple space-separated line keywords and combines them.
resolveTextDecorationStyle(String present) → TextDecorationStyle
resolveTextOverflow(String value) → TextOverflow
resolveTextShadow(String value, RenderStyle renderStyle, String propertyName) → List<Shadow>
resolveTextTransform(String value) → TextTransform
resolveWhiteSpace(String value) → WhiteSpace
resolveWordBreak(String value) → WordBreak
supportsFontFeature(CSSRenderStyle renderStyle, String tag) → bool
supportsSmallCapsFontFeature(CSSRenderStyle renderStyle) → bool
toCharacterBreakStr(String? word) → String?