CSSVariable class

Constructors

CSSVariable(String identifier, RenderStyle _renderStyle, {dynamic defaultValue})

Properties

defaultValue → dynamic
final
hashCode → int
The hash code for this object.
no setteroverride
identifier → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

computedValue(String propertyName) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

isCSSSVariableProperty(String? value) → bool
isCSSVariableValue(String? value) → bool
tryParse(RenderStyle renderStyle, String propertyValue) → CSSVariable?