CalcOperationExpressionNode class

Inheritance

Constructors

CalcOperationExpressionNode(int operator, CalcExpressionNode leftNode, CalcExpressionNode rightNode)

Properties

computedValue → double
no setteroverride
hashCode → int
The hash code for this object.
no setteroverride
leftNode → CalcExpressionNode
final
operator ↔ int
getter/setter pair
rightNode → CalcExpressionNode
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override