EffectTiming class

Constructors

EffectTiming({double? duration = 0, double? delay = 0, double? endDelay = 0, double? iterationStart = 0, double? iterations = 1, String easing = 'linear', PlaybackDirection? direction = PlaybackDirection.normal, FillMode? fill = FillMode.auto})

Properties

delay ↔ double?
getter/setter pair
direction ↔ PlaybackDirection?
getter/setter pair
duration ↔ double?
getter/setter pair
easing ↔ String?
getter/setter pair
endDelay ↔ double?
getter/setter pair
fill ↔ FillMode?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
iterations ↔ double?
getter/setter pair
iterationStart ↔ double?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited