ElementRuleCollector class

Constructors

ElementRuleCollector()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildAncestorTokens(Element element) → SelectorAncestorTokenSet
canActivatePseudoClassOnTarget(RuleSet ruleSet, Element element, String pseudoClassName) → bool
collectionFromRuleSet(RuleSet ruleSet, Element element, {SelectorAncestorTokenSet? ancestorTokens, SelectorEvaluator? evaluator}) → CSSStyleDeclaration
gotoReturn(List<CSSStyleRule> matchedRules) → void
matchedAnyRule(RuleSet ruleSet, Element element) → bool
matchedPseudoRules(RuleSet ruleSet, Element element, {SelectorAncestorTokenSet? ancestorTokens, SelectorEvaluator? evaluator}) → List<CSSStyleRule>
matchedRules(RuleSet ruleSet, Element element, {SelectorAncestorTokenSet? ancestorTokens, SelectorEvaluator? evaluator}) → List<CSSStyleRule>
matchedRulesForInvalidate(RuleSet ruleSet, Element element) → List<CSSRule>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited