ExtendedBorderSide class

Inheritance

Constructors

ExtendedBorderSide({Color color = const Color(0xFF000000), double strokeAlign = strokeAlignInside, BorderStyle style = BorderStyle.solid, double width = 1.0, required CSSBorderStyleType extendBorderStyle})
const

Properties

color → Color
The color of this side of the border.
finalinherited
extendBorderStyle → CSSBorderStyleType
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
strokeAlign → double
The relative position of the stroke on a BorderSide in an OutlinedBorder or Border.
finalinherited
strokeInset → double
Get the amount of the stroke width that lies inside of the BorderSide.
no setterinherited
strokeOffset → double
The offset of the stroke, taking into account the stroke alignment.
no setterinherited
strokeOutset → double
Get the amount of the stroke width that lies outside of the BorderSide.
no setterinherited
style → BorderStyle
The style of this side of the border.
finalinherited
width → double
The width of this side of the border, in logical pixels.
finalinherited

Methods

copyWith({Color? color, double? width, BorderStyle? style, double? strokeAlign}) → BorderSide
Creates a copy of this border but with the given fields replaced with the new values.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scale(double t) → BorderSide
Creates a copy of this border side description but with the width scaled by the factor t.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toPaint() → Paint
Create a Paint object that, if used to stroke a line, will draw the line in this border's style.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited