GridPlacement class

Constructors

GridPlacement.auto()
const
GridPlacement.line(int value)
const
GridPlacement.named(String name, {int? occurrence, bool explicitOccurrence = false})
const
GridPlacement.span(int value)
const

Properties

hasExplicitLineNameOccurrence → bool
final
hashCode → int
The hash code for this object.
no setterinherited
kind → GridPlacementKind
final
line → int?
final
lineName → String?
final
lineNameOccurrence → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
span → int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited