GridRepeat class

Inheritance

Constructors

GridRepeat.autoFill(List<GridTrackSize> tracks, {List<String> leadingLineNames = const <String>[], List<String> trailingLineNames = const <String>[]})
const
GridRepeat.autoFit(List<GridTrackSize> tracks, {List<String> leadingLineNames = const <String>[], List<String> trailingLineNames = const <String>[]})
const
GridRepeat.count(int repeatCount, List<GridTrackSize> tracks, {List<String> leadingLineNames = const <String>[], List<String> trailingLineNames = const <String>[]})
const

Properties

count → int?
final
hashCode → int
The hash code for this object.
no setterinherited
isAutoFit → bool
finalinherited
kind → GridRepeatKind
final
leadingLineNames → List<String>
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tracks → List<GridTrackSize>
final
trailingLineNames → List<String>
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited