GridTemplateAreaRect class

Constructors

GridTemplateAreaRect(int rowStart, int rowEnd, int columnStart, int columnEnd)
const

Properties

columnEnd → int
final
columnSpan → int
no setter
columnStart → int
final
hashCode → int
The hash code for this object.
no setterinherited
rowEnd → int
final
rowSpan → int
no setter
rowStart → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited