GridTrackSize class abstract

Grid track size model for CSS Grid (subset for MVP).

Implementers

Constructors

GridTrackSize({List<String> leadingLineNames = const <String>[], List<String> trailingLineNames = const <String>[], bool isAutoFit = false})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
isAutoFit → bool
final
leadingLineNames → List<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trailingLineNames → List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited