Keyframe class

Constructors

Keyframe(String property, String value, double offset, [String? easing])

Properties

easing ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
offset ↔ double
getter/setter pair
property ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited