RenderStyle class abstract

The abstract class for render-style, declare the getter interface for all available CSS rule.

Inheritance
Mixed-in types
Implementers

Constructors

RenderStyle()

Properties

alignContent → AlignContent
no setter
alignItems → AlignItems
no setter
alignSelf → AlignSelf
no setter
animationDelay → List<String>
no setter
animationDirection → List<String>
no setter
animationDuration → List<String>
no setter
animationFillMode → List<String>
no setter
animationIterationCount → List<String>
no setter
animationName → List<String>
no setter
animationPlayState → List<String>
no setter
animationTimingFunction → List<String>
no setter
aspectRatio → double?
no setter
attachedRenderBoxModel → RenderBoxModel?
no setter
attachedRenderObjectElement → RenderObjectElement?
no setter
backgroundAttachment → CSSBackgroundAttachmentType?
no setter
backgroundClip → CSSBackgroundBoundary?
no setter
backgroundColor → CSSColor?
no setter
backgroundImage → CSSBackgroundImage?
no setter
backgroundOrigin → CSSBackgroundBoundary?
no setter
backgroundPositionX → CSSBackgroundPosition
no setter
backgroundPositionY → CSSBackgroundPosition
no setter
backgroundRepeat → CSSBackgroundRepeatType
no setter
backgroundSize → CSSBackgroundSize
no setter
boldText → bool
no setter
border → EdgeInsets
no setter
borderBottomColor → CSSColor
no setter
borderBottomLeftRadius → CSSBorderRadius
no setter
borderBottomRightRadius → CSSBorderRadius
no setter
borderBottomStyle → CSSBorderStyleType
no setter
borderBottomWidth → CSSLengthValue?
no setter
borderBoxHeight → double?
no setter
borderBoxLogicalHeight → double?
no setter
borderBoxLogicalWidth → double?
no setter
borderBoxWidth → double?
no setter
borderEndEndRadius → CSSBorderRadius
no setter
borderEndStartRadius → CSSBorderRadius
no setter
borderLeftColor → CSSColor
no setter
borderLeftStyle → CSSBorderStyleType
no setter
borderLeftWidth → CSSLengthValue?
no setter
borderRadius → List<Radius>?
no setter
borderRightColor → CSSColor
no setter
borderRightStyle → CSSBorderStyleType
no setter
borderRightWidth → CSSLengthValue?
no setter
borderSides → List<BorderSide>?
no setter
borderStartEndRadius → CSSBorderRadius
no setter
borderStartStartRadius → CSSBorderRadius
no setter
borderTopColor → CSSColor
no setter
borderTopLeftRadius → CSSBorderRadius
no setter
borderTopRightRadius → CSSBorderRadius
no setter
borderTopStyle → CSSBorderStyleType
no setter
borderTopWidth → CSSLengthValue?
no setter
bottom → CSSLengthValue
no setter
caretColor → Color?
no setter
color → CSSColor
no setter
colorFilter → ColorFilter?
no setter
columnGap → CSSLengthValue
no setter
contentBoxHeight → double?
no setter
contentBoxLogicalHeight → double?
no setter
contentBoxLogicalWidth → double?
no setter
contentBoxWidth → double?
no setter
contentMaxConstraintsWidth → double
no setter
contentVisibility → ContentVisibility
no setter
currentColor → CSSColor
no setter
currentFlutterView → FlutterView
no setter
direction → TextDirection
no setter
display → CSSDisplay
no setter
effectiveBorderBottomWidth → CSSLengthValue
no setter
effectiveBorderLeftWidth → CSSLengthValue
no setter
effectiveBorderRightWidth → CSSLengthValue
no setter
effectiveBorderTopWidth → CSSLengthValue
no setter
effectiveDisplay → CSSDisplay
no setter
effectiveOverflowX → CSSOverflowType
no setter
effectiveOverflowY → CSSOverflowType
no setter
effectiveTransformMatrix → Matrix4?
no setter
effectiveTransformScale → double
no setter
establishesStackingContext → bool
no setter
filter → List<CSSFunctionalNotation>?
no setter
filterDropShadows → List<CSSBoxShadow>?
no setter
flexBasis → CSSLengthValue?
no setter
flexDirection → FlexDirection
no setter
flexGrow → double
no setter
flexShrink → double
no setter
flexWrap → FlexWrap
no setter
fontFamily → List<String>?
no setter
fontSize → CSSLengthValue
no setter
fontStyle → FontStyle
no setter
fontVariant → String
no setter
fontWeight → FontWeight
no setter
gap → CSSLengthValue
no setter
gridAreaName → String?
no setter
gridAutoColumns → List<GridTrackSize>
no setter
gridAutoFlow → GridAutoFlow
no setter
gridAutoRows → List<GridTrackSize>
no setter
gridColumnEnd → GridPlacement
no setter
gridColumnStart → GridPlacement
no setter
gridRowEnd → GridPlacement
no setter
gridRowStart → GridPlacement
no setter
gridTemplateAreasDefinition → GridTemplateAreasDefinition?
no setter
gridTemplateColumns → List<GridTrackSize>
no setter
gridTemplateRows → List<GridTrackSize>
no setter
hashCode → int
The hash code for this object.
no setterinherited
height → CSSLengthValue
no setter
imageFilter → ImageFilter?
no setter
intrinsicHeight → double
no setter
intrinsicWidth → double
no setter
isHeightStretch → bool
no setter
isWidthStretch → bool
no setter
justifyContent → JustifyContent
no setter
justifyItems → GridAxisAlignment
no setter
justifySelf → GridAxisAlignment
no setter
left → CSSLengthValue
no setter
letterSpacing → CSSLengthValue?
no setter
lineClamp → int?
no setter
lineHeight → CSSLengthValue
no setter
margin → EdgeInsets
no setter
marginBottom → CSSLengthValue
no setter
marginLeft → CSSLengthValue
no setter
marginRight → CSSLengthValue
no setter
marginTop → CSSLengthValue
no setter
maxHeight → CSSLengthValue
no setter
maxWidth → CSSLengthValue
no setter
minHeight → CSSLengthValue
no setter
minWidth → CSSLengthValue
no setter
needsStacking → bool
no setter
objectFit → BoxFit
no setter
objectPosition → Alignment
no setter
opacity → double
no setter
order → int
no setter
overflowX → CSSOverflowType
no setter
overflowY → CSSOverflowType
no setter
padding → EdgeInsets
no setter
paddingBottom → CSSLengthValue
no setter
paddingBoxHeight → double?
no setter
paddingBoxLogicalHeight → double?
no setter
paddingBoxLogicalWidth → double?
no setter
paddingBoxWidth → double?
no setter
paddingLeft → CSSLengthValue
no setter
paddingRight → CSSLengthValue
no setter
paddingTop → CSSLengthValue
no setter
parent → RenderStyle?
no setter
position → CSSPositionType
no setter
no setter
rootFontSize → double
no setter
rowGap → CSSLengthValue
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shadows → List<WebFBoxShadow>?
no setter
sliverDirection → Axis
no setter
target → Element
no setter
textAlign → TextAlign
no setter
textOverflow → TextOverflow
no setter
textScaler → TextScaler
no setter
textShadow → List<Shadow>?
no setter
top → CSSLengthValue
no setter
transform → List<CSSFunctionalNotation>?
no setter
transformOrigin → CSSOrigin
no setter
transitionDelay → List<String>
no setter
transitionDuration → List<String>
no setter
transitionProperty → List<String>
no setter
transitionTimingFunction → List<String>
no setter
verticalAlign → VerticalAlign
no setter
viewportSize → Size
no setter
visibility → Visibility
no setter
whiteSpace → WhiteSpace
no setter
widgetRenderObjectIterator → Iterable<RenderBoxModel>
no setter
widgetRenderObjects → Map<RenderObjectElement, RenderBoxModel>
no setter
width → CSSLengthValue
no setter
wordBreak → WordBreak
no setter
wordSpacing → CSSLengthValue?
no setter
writingMode → CSSWritingMode
no setter
zIndex → int?
no setter

Methods

addColorRelativeProperty(String propertyName) → void
addFontRelativeProperty(String propertyName) → void
addIntersectionChangeListener(IntersectionChangeCallback entryCallback, List<double> thresholds) → void
addOrUpdateWidgetRenderObjects(RenderObjectElement ownerRenderObjectElement, RenderBoxModel targetRenderBoxModel) → void
addRootFontRelativeProperty(String propertyName) → void
addViewportSizeRelativeProperty() → void
boxSize() → Size?
cleanContentBoxLogiclHeight() → void
cleanContentBoxLogiclWidth() → void
clearIntersectionChangeListeners([RenderObjectElement? flutterWidgetElement]) → void
clientHeight() → double?
clientWidth() → double?
constraints() → BoxConstraints
contentConstraints() → BoxConstraints?
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
dispose() → void
ensureEventResponderBound() → void
everyAttachedRenderObjectByTypeAndMatch(RenderObjectGetType getType, RenderObjectMatchers matcher) → bool
everyAttachedWidgetRenderBox(EveryRenderBoxModelHandlerCallback callback) → bool
everyRenderBox(EveryRenderBoxModelHandlerCallback callback) → bool
everyRenderObjectByTypeAndMatch(RenderObjectGetType getType, RenderObjectMatchers matcher) → bool
everyWidgetRenderBox(EveryRenderBoxModelHandlerCallback callback) → bool
getAttachedRenderParentRenderStyle<T extends RenderStyle>() → T?
getCSSVariable(String identifier, String propertyName) → dynamic
getCurrentViewportBox() → RenderViewportBox?
getFirstChildRenderStyle<T extends RenderStyle>() → T?
getHeightByAspectRatio() → double
getLastChildRenderStyle<T extends RenderStyle>() → T?
getNextSiblingRenderStyle<T extends RenderStyle>() → T?
getOffset({RenderBoxModel? ancestorRenderBox, bool excludeScrollOffset = false}) → Offset
getPreviousSiblingRenderStyle<T extends RenderStyle>() → T?
getProperty(String key) → dynamic
getRenderBoxValueByType(RenderObjectGetType getType, RenderBoxModelGetter getter) → dynamic
getSelfPositionPlaceHolder() → RenderPositionPlaceholder?
getSelfRenderBox(RenderObjectElement? flutterWidgetElement) → RenderBoxModel?
getSelfRenderBoxValue(RenderBoxModelGetter getter) → dynamic
getSelfRenderStyle<T extends RenderStyle>() → T?
getWidgetPairedRenderBoxModel(Element targetRenderObjectElement) → RenderBoxModel?
getWidthByAspectRatio() → double
hasRenderBox() → bool
heightSizeType() → BoxSizeType
isBoxModel() → bool
isBoxModelHaveSize() → bool
isDocumentRootBox() → bool
isFirstChildAreRenderBoxModel() → bool
isFirstChildAreRenderFlowLayoutBox() → bool
isFirstChildStyleMatch(RenderStyleMatcher matcher) → bool
isLastChildAreRenderBoxModel() → bool
isLastChildAreRenderLayoutBox() → bool
isLastChildStyleMatch(RenderStyleMatcher matcher) → bool
isLayoutBox() → bool
isNextSiblingAreRenderObject() → bool
isParentBoxModelMatch(RenderBoxModelMatcher matcher) → bool
isParentDocumentRootBox() → bool
isParentRenderBoxModel() → bool
isParentRenderFlexLayout() → bool
isParentRenderFlowLayout() → bool
isParentRenderGridLayout() → bool
isParentRenderLayoutBox() → bool
isParentRenderViewportBox() → bool
isPositionHolderParentIsRenderFlexLayout() → bool
isPositionHolderParentIsRenderLayoutBox() → bool
isPreviousSiblingAreRenderObject() → bool
isPreviousSiblingStyleMatch(RenderStyleMatcher matcher) → bool
isRepaintBoundary() → bool
isSelfAnonymousFlowLayout() → bool
isSelfBoxModelMatch(RenderBoxModelMatcher matcher) → bool
isSelfBoxModelSizeTight() → bool
isSelfContainsRenderPositionPlaceHolder() → bool
isSelfHTMLElement() → bool
isSelfNeedsRelayout() → bool
isSelfParentDataAreRenderLayoutParentData() → bool
isSelfPositioned() → bool
isSelfRenderBoxAttached() → bool
isSelfRenderBoxAttachedToSegmentTree() → bool
isSelfRenderFlexLayout() → bool
isSelfRenderFlowLayout() → bool
isSelfRenderGridLayout() → bool
isSelfRenderLayoutBox() → bool
isSelfRenderReplaced() → bool
isSelfRenderWidget() → bool
isSelfRouterLinkElement() → bool
isSelfScrollingContainer() → bool
isSelfStickyPosition() → bool
localToGlobal(Offset point, {RenderObject? ancestor}) → Offset
markChildrenNeedsSort() → void
markNeedsBuild() → void
markNeedsCompositingBitsUpdate() → void
markNeedsInlineCollection() → void
markNeedsIntrinsicMeasurement([String reason = 'renderStyle']) → void
markNeedsLayout() → void
markNeedsPaint() → void
markNeedsRelayout() → void
markParentNeedsLayout() → void
markParentNeedsRelayout() → void
markParentNeedsSort() → void
markPositionHolderParentNeedsLayout() → void
markSelfAndParentBoxModelNeedsLayout() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeAllRenderObject() → void
removeIntersectionChangeListener(IntersectionChangeCallback entryCallback) → void
removeRenderObject(Element? flutterWidgetElement) → void
requestWidgetToRebuild(AdapterUpdateReason reason) → void
resetBoxDecoration() → void
resolveValue(String property, String present) → dynamic
Resolve the style value.
scrollableSize() → Size?
setCSSVariable(String identifier, String value) → void
setDebugShouldPaintOverlay(bool value) → void
someRenderBoxSatisfy(SomeRenderBoxModelHandlerCallback callback) → bool
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toImage(double pixelRatio) → Future<Image>
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
override
unmountWidgetRenderObject(Element ownerRenderObjectElement) → void
visitChildren(RenderObjectVisitor visitor) → void
widthSizeType() → BoxSizeType

Operators

operator ==(Object other) → bool
The equality operator.
inherited