RuleSet class

Constructors

RuleSet(Document ownerDocument)

Properties

attributeRules → CSSMap
final
classRules → CSSMap
final
hasActivePseudo ↔ bool
getter/setter pair
hasHasPseudo ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hasHoverPseudo ↔ bool
getter/setter pair
idRules → CSSMap
final
isEmpty → bool
no setter
keyframesRules → Map<String, CSSKeyframesRule>
final
layerTree → CascadeLayerTree
final
ownerDocument → Document
final
pseudoRules → List<CSSRule>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tagRules → CSSMap
final
universalRules → List<CSSRule>
final

Methods

addRule(CSSRule rule, {required String? baseHref}) → void
addRules(List<CSSRule> rules, {required String? baseHref}) → void
findBestRuleSetAndAdd(Selector selector, CSSRule rule) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited