Selector class

Inheritance

Constructors

Selector(List<SimpleSelectorSequence> simpleSelectorSequences)

Properties

descendantAncestorHints → SelectorAncestorHints
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasInvalid → bool
no setter
hasPseudoElement → bool
no setter
length → int
no setter
matchGroupCombinators → List<int>
no setter
matchGroups → List<List<SimpleSelector>>
no setter
pseudoElementMask → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
simpleSelectorSequences → List<SimpleSelectorSequence>
final
specificity → int
no setter

Methods

add(SimpleSelectorSequence seq) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
visit(Visitor visitor) → dynamic
Classic double-dispatch visitor for implementing passes.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited