SelectorAncestorHints class

Constructors

SelectorAncestorHints()

Properties

classes Set<String>
final
hashCode int
The hash code for this object.
no setterinherited
ids Set<String>
final
isEmpty bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags Set<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited