SelectorAncestorTokenSet class

Constructors

SelectorAncestorTokenSet.eager({required Set<String> ids, required Set<String> classes, required Set<String> tags})
factory
SelectorAncestorTokenSet.lazy(Element element)
factory

Properties

classes → Set<String>
no setter
hashCode → int
The hash code for this object.
no setterinherited
ids → Set<String>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → Set<String>
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited