TextScriptSegment class

Constructors

TextScriptSegment({required int start, required int end, required String text, required bool isCJK})

Properties

end → int
final
hashCode → int
The hash code for this object.
no setterinherited
isCJK → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → int
final
text → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited