TokenizerState class

Tokenizer state to support look ahead for Less' nested selectors.

Implementers

Constructors

TokenizerState(TokenizerBase base)

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
final
inSelector → bool
final
inSelectorExpression → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startIndex → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited