InspectOverlayModule class

Inheritance

Constructors

InspectOverlayModule(DevToolsService devtoolsService)

Properties

context → DebuggingContext?
Get the debugging context if available
no setterinherited
controller → WebFController?
Legacy controller access for backward compatibility
no setterinherited
dbgContext → DebuggingContext?
no setter
devtoolsService → DevToolsService
finalinherited
document → Document?
no setter
hashCode → int
The hash code for this object.
no setterinherited
isEnabled → bool
no setterinherited
name → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

invoke(int? id, String method, Map<String, dynamic>? params) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onContextChanged() → void
Called when the debugging context changes (e.g., when switching controllers) Subclasses can override this to reinitialize their state
inherited
onDisabled() → void
inherited
onEnabled() → void
inherited
onHideHighlight(int? id) → void
onHighlightNode(int? id, Map<String, dynamic> params) → void
https://chromedevtools.github.io/devtools-protocol/tot/Overlay/#method-highlightNode
onHighlightRect(int? id, Map<String, dynamic> params) → void
Approximate Overlay.highlightRect behavior by hit-testing the rect center and applying element highlight. This keeps implementation minimal and non-invasive to the render pipeline.
receiveFromFrontend(int? id, String method, Map<String, dynamic>? params) → void
sendEventToFrontend(InspectorEvent event) → void
inherited
sendToFrontend(int? id, JSONEncodable? result) → void
inherited
setEnabled(bool enabled) → void
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited