InspectPageModule class

Inheritance

Constructors

InspectPageModule(DevToolsService devtoolsService)

Properties

context → DebuggingContext?
Get the debugging context if available
no setterinherited
controller → WebFController?
Legacy controller access for backward compatibility
no setterinherited
devtoolsService → DevToolsService
finalinherited
document → Document?
no setter
hashCode → int
The hash code for this object.
no setterinherited
isEnabled → bool
no setterinherited
isScreencastActive → bool
Gets whether screencast is currently active
no setter
name → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

handleGetFrameResourceTree(int? id, Map<String, dynamic> params) → void
handleReloadPage() → void
handleScreencastFrameAck(Map<String, dynamic> params) → void
Avoiding frame blocking, confirm frontend has ack last frame, and then send next frame.
invoke(int? id, String method, Map<String, dynamic>? params) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onContextChanged() → void
Called when the debugging context changes (e.g., when switching controllers) Subclasses can override this to reinitialize their state
inherited
onDisabled() → void
inherited
onEnabled() → void
inherited
receiveFromFrontend(int? id, String method, Map<String, dynamic>? params) → void
sendEventToFrontend(InspectorEvent event) → void
inherited
sendToFrontend(int? id, JSONEncodable? result) → void
inherited
setEnabled(bool enabled) → void
inherited
startScreenCast() → void
stopScreenCast() → void
toString() → String
A string representation of this object.
inherited
transferScreencastState(InspectPageModule fromModule) → void
Transfers screencast state from another Page module (used during controller switch)

Operators

operator ==(Object other) → bool
The equality operator.
inherited