NetworkLoadingFailedEvent class

Inheritance

Constructors

NetworkLoadingFailedEvent({required String requestId, required double timestamp, required String type, required String errorText, bool canceled = false})

Properties

canceled → bool
final
errorText → String
final
hashCode → int
The hash code for this object.
no setterinherited
method → String
no setteroverride
params → JSONEncodable?
no setteroverride
requestId → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → double
final
type → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited