TargetCreatedEvent class

Inheritance

Constructors

TargetCreatedEvent({required Map<String, dynamic> targetInfo})

Properties

hashCode → int
The hash code for this object.
no setterinherited
method → String
no setteroverride
params → JSONEncodable?
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetInfo → Map<String, dynamic>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited