UnifiedChromeDevToolsService class

Unified DevTools service that manages debugging for all WebF controllers

Properties

currentContext → DebuggingContext?
no setter
currentController → WebFController?
no setter
currentService → ChromeDevToolsService?
no setter
devToolsUrl → String?
Gets the DevTools connection URL if the server is running
no setter
hashCode → int
The hash code for this object.
no setterinherited
isContextSwitching → bool
Returns true if currently switching between contexts
no setter
isRunning → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addEventListenerForTest(void listener(InspectorEvent)) → void
clearDOMPanel() → void
Public method to clear DOM panel (called from controller detach)
clearEventListenersForTest() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendEventToFrontend(InspectorEvent event) → void
sendMethodResult(int id, Map<String, dynamic> result) → void
start({String? address, int? port}) → Future<void>
Start the DevTools server
stop() → Future<void>
Stop the DevTools server
switchToContext(DebuggingContext context) → void
Switch DevTools to a specific context
switchToController(WebFController controller) → void
Switch DevTools to a specific controller (called when controller is attached)
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited