BoxFitImage class

Inheritance

Constructors

BoxFitImage({required LoadImage loadImage, required Uri url, required BoxFit boxFit, required double devicePixelRatio, required double contextId, required Pointer<NativeBindingObject> targetElementPtr, OnImageLoad? onImageLoad})

Properties

boxFit → BoxFit
final
contextId → double
final
devicePixelRatio → double
final
hashCode → int
The hash code for this object.
no setterinherited
onImageLoad → OnImageLoad?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetElementPtr → Pointer<NativeBindingObject>
final
url → Uri
final

Methods

createStream(ImageConfiguration configuration) → ImageStream
Called by resolve to create the ImageStream it returns.
inherited
evict({ImageCache? cache, ImageConfiguration configuration = ImageConfiguration.empty}) → Future<bool>
Evicts an entry from the image cache.
inherited
loadBuffer(BoxFitImageKey key, DecoderBufferCallback decode) → ImageStreamCompleter
Converts a key into an ImageStreamCompleter, and begins fetching the image.
inherited
loadImage(BoxFitImageKey key, ImageDecoderCallback decode) → ImageStreamCompleter
Converts a key into an ImageStreamCompleter, and begins fetching the image.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
obtainCacheStatus({required ImageConfiguration configuration, ImageErrorListener? handleError}) → Future<ImageCacheStatus?>
Returns the cache location for the key that this ImageProvider creates.
inherited
obtainKey(ImageConfiguration configuration) → Future<BoxFitImageKey>
Converts an ImageProvider's settings plus an ImageConfiguration to a key that describes the precise image to load.
override
resolve(ImageConfiguration configuration) → ImageStream
Resolves this image provider using the given configuration, returning an ImageStream.
inherited
resolveStreamForKey(ImageConfiguration configuration, ImageStream stream, BoxFitImageKey key, ImageErrorListener handleError) → void
Called by resolve with the key returned by obtainKey.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited