WebFResizeImage class

Inheritance

Constructors

WebFResizeImage(ImageProvider<Object> imageProvider, {int? width, int? height, BoxFit? objectFit})
const

Properties

allowUpscaling → bool
Whether the width and height parameters should be clamped to the intrinsic width and height of the image.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
height → int?
The height the image should decode to and cache.
finalinherited
imageProvider → ImageProvider<Object>
The ImageProvider that this class wraps.
finalinherited
objectFit → BoxFit?
final
policy → ResizeImagePolicy
The policy that determines how width and height are interpreted.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → int?
The width the image should decode to and cache.
finalinherited

Methods

createStream(ImageConfiguration configuration) → ImageStream
Called by resolve to create the ImageStream it returns.
inherited
evict({ImageCache? cache, ImageConfiguration configuration = ImageConfiguration.empty}) → Future<bool>
Evicts an entry from the image cache.
inherited
loadBuffer(ResizeImageKey key, DecoderBufferCallback decode) → ImageStreamCompleter
Converts a key into an ImageStreamCompleter, and begins fetching the image.
inherited
loadImage(ResizeImageKey key, ImageDecoderCallback decode) → ImageStreamCompleter
Converts a key into an ImageStreamCompleter, and begins fetching the image.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
obtainCacheStatus({required ImageConfiguration configuration, ImageErrorListener? handleError}) → Future<ImageCacheStatus?>
Returns the cache location for the key that this ImageProvider creates.
inherited
obtainKey(ImageConfiguration configuration) → Future<ResizeImageKey>
Converts an ImageProvider's settings plus an ImageConfiguration to a key that describes the precise image to load.
inherited
resolve(ImageConfiguration configuration) → ImageStream
Resolves this image provider using the given configuration, returning an ImageStream.
inherited
resolveStreamForKey(ImageConfiguration configuration, ImageStream stream, ResizeImageKey key, ImageErrorListener handleError) → void
Called by resolve with the key returned by obtainKey.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

resizeIfNeeded(int? cacheWidth, int? cacheHeight, BoxFit? objectFit, ImageProvider<Object> provider) → ImageProvider<Object>
Composes the provider in a ResizeImage only when cacheWidth and cacheHeight are not both null.
override