ContentInfo class

Detailed information about visible content in a WebF page

Properties

customPaintElements ↔ int
Number of custom paint elements
getter/setter pair
decoratedElements ↔ int
Number of visible decorated elements (with backgrounds, borders, etc)
getter/setter pair
description → String
Returns a human-readable description of the content
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasVisibleContent ↔ bool
Whether the page has any visible content
getter/setter pair
imageElements ↔ int
Number of visible image elements
getter/setter pair
isBlank → bool
Returns true if the page appears to be blank
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textElements ↔ int
Number of visible text elements
getter/setter pair
totalElements ↔ int
Total number of visible elements
getter/setter pair
totalVisibleArea ↔ double
Total visible area in pixels squared
getter/setter pair
widgetElements ↔ int
Number of visible widget elements
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited