InlineFormattingContext class

Manages the inline formatting context for a block container. Based on Blink's InlineNode.

Constructors

InlineFormattingContext({required RenderLayoutBox container})

Properties

container → RenderLayoutBox
The block container that establishes this inline formatting context.
final
hashCode → int
The hash code for this object.
no setterinherited
isPlainTextOnlyForSharedReuse → bool
no setter
items → List<InlineItem>
no setter
paragraph → Paragraph?
no setter
paragraphLeftShift → double
no setter
paragraphLineMetrics → List<LineMetrics>
no setter
paragraphMaxIntrinsicWidth → double
no setter
paragraphMinIntrinsicWidth → double
no setter
paragraphVisualMaxLineWidth → double
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textContent → String
no setter

Methods

additionalOverflowHeightFromAtomicPlaceholders() → double
additionalPositiveXOverflowFromAtomicPlaceholders() → double
additionalPositiveYOffsetFromAtomicPlaceholders() → double
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add debugging information for the inline formatting context.
dispose() → void
elementHasRightExtrasPlaceholder(RenderBoxModel box) → bool
getBoundsForRenderBox(RenderBox targetBox) → Rect?
Get the bounding rectangle for a specific inline element across all line fragments.
hitTest(BoxHitTestResult result, {required Offset position}) → bool
Hit test the inline content.
inlineAdvanceForDescendant(RenderObject descendant) → double
inlineElementBoundingRect(RenderBoxModel box) → Rect?
inlineElementMaxLineHeight(RenderBoxModel box) → double
inlineElementMaxLineWidth(RenderBoxModel box) → double
inlineElementTotalHeight(RenderBoxModel box) → double
layout(BoxConstraints constraints) → Size
Perform layout with given constraints.
layoutReuseSignature(BoxConstraints constraints) → int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(PaintingContext context, Offset offset) → void
Paint the inline content.
plainTextSharedReuseSignature() → int
prepareLayout() → void
Prepare for layout by collecting inlines and shaping text.
relayoutParagraphToWidth(double width) → void
setNeedsCollectInlines() → void
Mark that inline collection is needed.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited