IntersectionObserverEntry class

Annotations

Constructors

IntersectionObserverEntry({Rect? boundingClientRect, Rect? intersectionRect, Rect? rootBounds, Size? size})
const
IntersectionObserverEntry.fromRects({required Rect boundingClientRect, required Rect rootBounds})
Constructs a IntersectionObserverEntry from element bounds and a corresponding clipping rectangle.
factory

Properties

boundingClientRect → Rect
Returns the bounds rectangle of the target element.
final
hashCode → int
The hash code for this object.
no setterinherited
intersectionRatio → double
A fraction in the range [0, 1] that represents what proportion of the element is visible (assuming rectangular bounding boxes).
no setter
intersectionRect → Rect
The visible portion of the element, in the element's local coordinates.
final
isIntersecting → bool
no setter
rootBounds → Rect
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → Size
The size of the element.
final

Methods

matchesIntersecting(IntersectionObserverEntry info) → bool
Returns true if the specified IntersectionObserverEntry object has equivalent visibility to this one.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited