ResizeObserverEntry class

Constructors

ResizeObserverEntry({Size? borderBoxSize, Size? contentBoxSize, Size? devicePixelContentBoxSize, Size? contentRect})

Properties

borderBoxSize → Size
final
contentBoxSize → Size
final
contentRect → Size
final
devicePixelContentBoxSize → Size
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
target ↔ EventTarget
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited