RunMetrics class

Constructors

RunMetrics(double mainAxisExtent, double crossAxisExtent, List<RenderBox> runChildren, {double? baseline})

Properties

baseline → double?
final
crossAxisExtent → double
final
hashCode → int
The hash code for this object.
no setterinherited
mainAxisExtent → double
final
runChildren → List<RenderBox>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited