FpsInfo class

Constructors

FpsInfo(FrameTiming frameTiming)

Properties

fps → int
no setter
frameTiming → FrameTiming
final
gpuSpan → double
The duration in milliseconds to rasterize the frame on the GPU thread.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalSpan → double
The duration in milliseconds during a lifetime of a frame.
no setter
uiSpan → double
The duration in milliseconds to build the frame on the UI thread.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited