ChildNodeList class

Inheritance

Constructors

ChildNodeList(ContainerNode rootNode)

Properties

canTraverseBackward bool
no setter
first Node
The first element.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isChildNodeList bool
no setteroverride
isEmpty bool
Whether this collection has no elements.
no setteroverride
isEmptyNodeList bool
no setterinherited
isNotEmpty bool
Whether this collection has at least one element.
no setteroverride
iterator Iterator<Node>
A new Iterator that allows iterating the elements of this Iterable.
no setteroverride
last Node
The last element.
no setterinherited
length int
The number of elements in this Iterable.
no setteroverride
ownerNode Node
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
single Node
Checks that this iterable has only one element, and returns that element.
no setterinherited

Methods

any(bool test(Node element)) bool
Checks whether any element of this iterable satisfies test.
inherited
cast<R>() Iterable<R>
A view of this iterable as an iterable of R instances.
inherited
childrenChanged(ChildrenChange change) → void
contains(Object? element) bool
Whether the collection contains an element equal to element.
inherited
elementAt(int index) Node
Returns the indexth element.
inherited
every(bool test(Node element)) bool
Checks whether every element of this iterable satisfies test.
inherited
expand<T>(Iterable<T> toElements(Node element)) Iterable<T>
Expands each element of this Iterable into zero or more elements.
inherited
firstWhere(bool test(Node element), {Node orElse()?}) Node
The first element that satisfies the given predicate test.
inherited
fold<T>(T initialValue, T combine(T previousValue, Node element)) → T
Reduces a collection to a single value by iteratively combining each element of the collection with an existing value
inherited
followedBy(Iterable<Node> other) Iterable<Node>
Creates the lazy concatenation of this iterable and other.
inherited
forEach(void action(Node element)) → void
Invokes action on each element of this iterable in iteration order.
inherited
invalidateCache() → void
item(int index) Node?
join([String separator = ""]) String
Converts each element to a String and concatenates the strings.
inherited
lastWhere(bool test(Node element), {Node orElse()?}) Node
The last element that satisfies the given predicate test.
inherited
map<T>(T toElement(Node e)) Iterable<T>
The current elements of this iterable modified by toElement.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reduce(Node combine(Node value, Node element)) Node
Reduces a collection to a single value by iteratively combining elements of the collection using the provided function.
inherited
singleWhere(bool test(Node element), {Node orElse()?}) Node
The single element that satisfies test.
inherited
skip(int count) Iterable<Node>
Creates an Iterable that provides all but the first count elements.
inherited
skipWhile(bool test(Node value)) Iterable<Node>
Creates an Iterable that skips leading elements while test is satisfied.
inherited
take(int count) Iterable<Node>
Creates a lazy iterable of the count first elements of this iterable.
inherited
takeWhile(bool test(Node value)) Iterable<Node>
Creates a lazy iterable of the leading elements satisfying test.
inherited
toList({bool growable = true}) List<Node>
Creates a List containing the elements of this Iterable.
inherited
toSet() Set<Node>
Creates a Set containing the same elements as this iterable.
inherited
toString() String
Returns a string representation of (some of) the elements of this.
inherited
toWidgetList() List<Widget>
traverseBackwardToOffset<T extends Node>(int offset, Node currentNode, List<int> currentOffset) → T?
traverseForwardToOffset<T extends Node>(int offset, Node currentNode, List<int> currentOffset) → T?
traverseToFirst<T extends Node>() → T?
traverseToLast<T extends Node>() → T?
where(bool test(Node element)) Iterable<Node>
Creates a new lazy Iterable with all elements that satisfy the predicate test.
inherited
whereType<T>() Iterable<T>
Creates a new lazy Iterable with all elements that have type T.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited