OnAppBarCreated typedef

OnAppBarCreated = PreferredSizeWidget Function(String title, RouterLinkElement routeLinkElement)

Signature for creating an AppBar for a WebF subview page.

The title is typically sourced from the current RouterLinkElement's title attribute. The routeLinkElement provides access to other attributes on the route node.

Implementation

typedef OnAppBarCreated = PreferredSizeWidget Function(String title, RouterLinkElement routeLinkElement);