contentLength property

  1. @override
int get contentLength
override

Gets and sets the content length of the request.

If the size of the request is not known in advance set content length to -1, which is also the default.

Implementation

@override
int get contentLength => _backendRequest?.contentLength ?? -1;
  1. @override
set contentLength (int value)
override

Gets and sets the content length of the request.

If the size of the request is not known in advance set content length to -1, which is also the default.

Implementation

@override
set contentLength(int value) {
  if (_backendRequest != null) {
    _backendRequest!.contentLength = value;
  }
}