flush method

  1. @override
Future flush()
override

Returns a Future that completes once all buffered data is accepted by the underlying StreamConsumer.

This method must not be called while an addStream is incomplete.

NOTE: This is not necessarily the same as the data being flushed by the operating system.

Implementation

@override
Future flush() async {
  if (_backendRequest == null) {
    await _createBackendClientRequest();
  }
  return _backendRequest!.flush();
}