QuickJSByteCodeCacheObject class

Constructors

QuickJSByteCodeCacheObject(String hash, String cacheDirectory, {Uint8List? bytes})

Properties

bytes ↔ Uint8List?
getter/setter pair
cacheDirectory → String
final
hash ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
valid → bool
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read() → Future<void>
Read the index file.
remove() → Future<void>
toString() → String
A string representation of this object.
inherited
write() → Future<void>

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

cacheMode ↔ ByteCodeCacheMode
getter/setter pair