Touch class

Constructors

Touch({required int identifier, required EventTarget target, double clientX = 0, double clientY = 0, double screenX = 0, double screenY = 0, double pageX = 0, double pageY = 0, double radiusX = 0, double radiusY = 0, double rotationAngle = 0, double force = 0, double altitudeAngle = 0, double azimuthAngle = 0})
const

Properties

altitudeAngle → double
final
azimuthAngle → double
final
clientX → double
final
clientY → double
final
force → double
final
hashCode → int
The hash code for this object.
no setterinherited
identifier → int
final
pageX → double
final
pageY → double
final
radiusX → double
final
radiusY → double
final
rotationAngle → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
screenX → double
final
screenY → double
final
target → EventTarget
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative(Pointer<NativeTouch> nativeTouch) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited