dispatchWindowPreloadedEvent method
void
dispatchWindowPreloadedEvent()
Dispatches the preloaded event to the window.
This custom WebF event fires when content has been preloaded using the preloading mode. JavaScript code can listen for this event to know when preloading has completed.
Implementation
void dispatchWindowPreloadedEvent() {
if (_preloadEventDispatched) return;
_preloadEventDispatched = true;
Event event = Event(EVENT_PRELOADED);
view.window.dispatchEvent(event);
}