dispatchWindowResizeEvent method

Future<void> dispatchWindowResizeEvent()

Dispatches the resize event to the window.

This is equivalent to the standard Web window.onresize event, which fires when the document view has been resized. In WebF, this occurs when the viewport size changes due to device rotation, window resizing, or other layout changes.

Returns a Future that completes when the event has been dispatched.

Implementation

Future<void> dispatchWindowResizeEvent() async {
  Event event = Event(EVENT_RESIZE);
  await view.window.dispatchEvent(event);
}