onLoad property

LoadHandler? onLoad
getter/setter pair

Callback triggered when the app is fully loaded, including DOM, CSS, JavaScript, and images.

This is equivalent to the window.onload event in web browsers and indicates all resources have been loaded and rendered.

Implementation

LoadHandler? onLoad;