controllerNames property

List<String> get controllerNames

Gets a list of all controller names currently registered with the manager

This property returns the names of all controllers, regardless of their state (attached, detached, or disposed).

Implementation

List<String> get controllerNames => _controllersByName.keys.toList();