getInstanceSync static method

WebFController? getInstanceSync(
  1. String name
)

Static convenience method to get a controller synchronously.

This is a static shorthand for calling instance.getControllerSync(name). It synchronously retrieves a controller by name without attempting recreation of disposed controllers.

name The unique name of the controller to retrieve.

Returns the controller if found and not disposed, null otherwise.

Implementation

static WebFController? getInstanceSync(String name) {
  return _instance.getControllerSync(name);
}