autoDisposeWhenLimitReached property
Whether to automatically dispose controllers when limits are exceeded.
When true, the manager will dispose the least recently used controllers when the maxAliveInstances limit is reached. When false, the limit acts as a soft limit and new controllers will still be created.
Implementation
final bool autoDisposeWhenLimitReached;