maxAttachedInstances property

int maxAttachedInstances
final

Maximum number of WebFController instances that can be attached to Flutter at the same time.

When this limit is reached and a new controller is attached, the least recently used attached controller will be detached (but not disposed).

Implementation

final int maxAttachedInstances;