onControllerDetached property

void Function(String name, WebFController controller)? onControllerDetached
final

Callback triggered when a controller is detached from Flutter.

This callback is invoked whenever a controller is detached, whether due to attachment limits being reached or explicit detachment by the application.

Implementation

final void Function(String name, WebFController controller)? onControllerDetached;