whiteSpace property
Implementation
@override
WhiteSpace get whiteSpace {
if (_whiteSpace != null) return _whiteSpace!;
_ensureLayoutPassInheritedTextCache();
if (_layoutPassInheritedWhiteSpace != null) {
return _layoutPassInheritedWhiteSpace!;
}
final WhiteSpace resolved = parent?.whiteSpace ?? WhiteSpace.normal;
if (_canUseLayoutPassInheritedTextCache) {
_layoutPassInheritedWhiteSpace = resolved;
}
return resolved;
}
set
whiteSpace
(WhiteSpace? value)
Implementation
set whiteSpace(WhiteSpace? value) {
if (_whiteSpace == value) return;
_whiteSpace = value;
markNeedsInlineCollection();
// Update all the children layout and text with specified style property not set due to style inheritance.
_markNestChildrenTextAndLayoutNeedsLayout(this, WHITE_SPACE);
}