HybridHistoryModule class
Methods
-
back()
→ void
-
-
canPop()
→ bool
-
Whether the navigator can be popped.
-
dispatchEvent({Event? event, dynamic data})
→ dynamic
-
inherited
-
dispose()
→ void
-
override
-
getBuildContextStack()
→ String
-
-
getState()
→ dynamic
-
-
initialize()
→ Future<void>
-
inherited
-
invoke(String method, List params)
→ dynamic
-
override
-
maybePop([Object? result])
→ Future<bool>
-
Pop the top-most route off, only if it's not the last route.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
path()
→ String
-
-
pop([Object? result])
→ void
-
Pop the current route - matches Flutter's Navigator.pop
-
popAndPushNamed(String routeName, {Object? arguments})
→ void
-
Pop the current route off and push a named route in its place.
-
popUntil(String routeName)
→ void
-
Pops until a route with the given name.
-
pushNamed(String routeName, {Object? arguments})
→ void
-
Push a named route onto the navigator - matches Flutter's Navigator.pushNamed
-
pushNamedAndRemoveUntil(Object? state, String newRouteName, String untilRouteName)
→ void
-
Push the route with the given name and remove routes until the predicate returns true.
Original API - kept for backward compatibility
-
pushNamedAndRemoveUntilRoute(String newRouteName, String untilRouteName, {Object? arguments})
→ void
-
Push the route with the given name and remove routes until named route is reached.
This is a more Flutter-like API
-
pushReplacementNamed(String routeName, {Object? arguments})
→ void
-
Push a replacement named route - matches Flutter's Navigator.pushReplacementNamed
-
pushState(Object? state, String name)
→ void
-
Push a named route onto the navigator that most tightly encloses the given
context.
Original API - kept for backward compatibility
-
replaceState(Object? state, String name)
→ void
-
Original API - kept for backward compatibility
-
restorablePopAndPushNamed(String routeName, {Object? arguments})
→ String
-
Restorably pop the current route and push a named route - matches Flutter's Navigator
-
restorablePopAndPushState(Object? state, String name)
→ String
-
Pop the current route off the navigator that most tightly encloses the
given context and push a named route in its place.
Original API - kept for backward compatibility
-
toString()
→ String
-
A string representation of this object.
inherited